@@ -1,6 +1,5 @@
 
 from django.contrib.auth import authenticate
-from django.contrib.auth.models import User
 from django.db.models import Q
 from django import forms
 from django.utils.translation import ugettext_lazy as _
@@ -8,9 +7,13 @@ from django.utils.translation import ugettext_lazy as _
 from mezzanine.accounts import get_profile_model, get_profile_user_fieldname
 from mezzanine.conf import settings
 from mezzanine.core.forms import Html5Mixin
+from mezzanine.utils.models import get_user_model
 from mezzanine.utils.urls import slugify
 
 
+User = get_user_model()
+
+
 class LoginForm(Html5Mixin, forms.Form):
     """
     Fields for login.
@@ -131,8 +134,8 @@ class ProfileForm(Html5Mixin, forms.ModelForm):
             if password1 != password2:
                 errors.append(_("Passwords do not match"))
             if len(password1) < settings.ACCOUNTS_MIN_PASSWORD_LENGTH:
-                errors.append(_("Password must be at least %s characters" %
-                              settings.ACCOUNTS_MIN_PASSWORD_LENGTH))
+                errors.append(_("Password must be at least %s characters") %
+                              settings.ACCOUNTS_MIN_PASSWORD_LENGTH)
             if errors:
                 self._errors["password1"] = self.error_class(errors)
         return password2
@@ -162,7 +165,7 @@ class ProfileForm(Html5Mixin, forms.ModelForm):
         if self._has_profile:
             profile = user.get_profile()
             profile_fields_form = self.get_profile_fields_form()
-            profile_fields_form(self.data, instance=profile).save()
+            profile_fields_form(self.data, self.files, instance=profile).save()
 
         if self._signup:
             settings.use_editable()
