@@ -203,8 +203,8 @@ def gravatar_url(email, size=32):
     """
     Return the full URL for a Gravatar given an email hash.
     """
-    email_hash = md5(email).hexdigest()
-    return "http://www.gravatar.com/avatar/%s?s=%s" % (email_hash, size)
+    bits = (md5(email.lower()).hexdigest(), size)
+    return "http://www.gravatar.com/avatar/%s?s=%s&d=identicon&r=PG" % bits
 
 
 @register.to_end_tag
